FixedBitSet

Struct FixedBitSet 

pub struct FixedBitSet<const BIT_COUNT: usize, const BYTE_COUNT: usize>(pub [u8; BYTE_COUNT]);
A fixed-size bit set encoded as a byte array.

Minecraft’s protocol calls this type Fixed BitSet(n). Bits are addressed from the least-significant bit of the first byte.

Tuple Fields

0: [u8; BYTE_COUNT]

Implementations

Source

impl<const BIT_COUNT: usize, const BYTE_COUNT: usize> FixedBitSet<BIT_COUNT, BYTE_COUNT>

pub fn bit(&self, idx: usize) -> bool

Returns whether the bit at idx is set.

Returns false if idx is outside the fixed bit range.

pub fn set(&mut self, idx: usize)

Sets the bit at idx.

Does nothing if idx is outside the fixed bit range.

pub fn clear(&mut self, idx: usize)

Clears the bit at idx.

Does nothing if idx is outside the fixed bit range.